@@ -19,7 +19,7 @@
 #      along with this program.
 #
 #  File: files.tcl
-#  Last change:  4 August 2011
+#  Last change:  10 October 2011
 #
 # See also files_foreign.tcl
 #  and metadata.tcl for properties of known file formats
@@ -503,25 +503,30 @@ proc SaveTRComp {file w} {
 	if { [SlowOpAborted] } { return }
 	puts $file "$n\t$d\t$la\t$lo\t$a\t$l\t$tl\t$dt\t$s\t$b"
     }
-    foreach k "frt.td frt.tt" {
-	puts $file [$w.$k cget -text]
+    foreach k {td tt} {
+	puts $file [$w.frt.$k cget -text]
     }
     if { [winfo exists $w.frtng] } {
-	foreach k "frtng.td frtng.tt" {
-	    puts $file [$w.$k cget -text]
+	foreach k {td tt} {
+	    puts $file [$w.frtng.$k cget -text]
 	}
     }
-    foreach k "frsp.avg frsp.max frsp.min" {
-	puts $file [$w.$k cget -text]
+    foreach k {avg max min} {
+	puts $file [$w.frsp.$k cget -text]
     }
     # RM contribution
-    foreach k "frrest.avg frrest.trt" {
-	puts $file [$w.$k cget -text]
+    foreach k {avg trt} {
+	puts $file [$w.frrest.$k cget -text]
     }
     #===
     if { [winfo exists $w.frmxnalt] } {
-	foreach k "frmxnalt.mx frmxnalt.mn frcad.cumula frcad.cumuld" {
-	    puts $file [$w.$k cget -text]
+	foreach k {mx mn} {
+	    puts $file [$w.frmxnalt.$k cget -text]
+	}
+	if { [winfo exists $w.frcad] } {
+	    foreach k {cumula cumuld thresh} {
+		puts $file [$w.frcad.$k cget -text]
+	    }
 	}
     }
     puts $file "[$w.frd0.toend cget -text] [$w.frd0.max cget -text]"
