@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2009 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,7 +19,7 @@
 #      along with this program.
 #
 #  File: garmin_protocols.tcl
-#  Last change:  30 July 2009
+#  Last change:  19 July 2011
 #
 
 # description of Garmin protocols based on
@@ -536,6 +538,7 @@ array set PRODID {
     "eTrex Summit HC" {695 786}
     "GPS 20x USB" 811
     "eTrex Legend H" 957
+    "GPS 72H" 1095
 }
 
     # product names and how to obain its product specific protocols
@@ -661,6 +664,7 @@ array set PNAME {
     786  "eTrex Summit/Venture HC"
     811  "GPS 20x USB"
     957  "eTrex Legend H"
+   1095  "GPS 72H"
 }
 
 # the descriptions below are valid for all versions except:
@@ -811,6 +815,7 @@ array set PRTCLDEF {
     786  see=694+
     811  diff
     957  diff
+   1095  diff
 }
 
 ### there is no information on which receivers use the PVT protocol
@@ -1452,6 +1457,7 @@ array set PSDIFF {
    696+ {696 {nospec A902+A903}}
    811  {273 {Baud N/A} {nospec A902+A903+A1010}}
    957  {421 {nospec A601+D601+A801+D801+A900+A902+A903+A904+A905+D900+A907+D907+D908+D909+D910+A908+D911+A914+A916+A918+D918}}
+  1095  {177 {Baud T001} {nospec A601+D601+A902+A903+A904+A907+D907+D908+D909+D910+A908+D910+A914}}
 }
 
 ## descriptions, positions in Garmin structures of GPSMan data
