@@ -1,11 +1,13 @@
 #
+# This file is part of:
+#
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2008 Miguel Filgueiras mig@ncc.up.pt Universidade do Porto
+# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
-#      the Free Software Foundation; either version 2 of the License, or
+#      the Free Software Foundation; either version 3 of the License, or
 #      (at your option) any later version.
 #
 #      This program is distributed in the hope that it will be useful,
@@ -17,7 +19,7 @@
 #      along with this program.
 #
 #  File: gdata.tcl
-#  Last change:  13 August 2007
+#  Last change:  19 July 2011
 #
 
 
@@ -295,7 +297,7 @@ proc GeoAdapt {type ix datum lts} {
 		set p [ToDatum $la $lo $WPDatum($wpix) $datum]
 		set la [lindex $p 0] ; set lo [lindex $p 1]
 	    }
-	    set alt [lindex $WPAlt($ix) 0]
+	    set alt [lindex $WPAlt($wpix) 0]
 	    lappend glts [linsert $tuple 0 $la $lo $alt]
 	    set wpns [lreplace $wpns 0 0]
 	}
