@@ -19,9 +19,9 @@
 #      along with this program.
 #
 #  File: langnl.tcl
-#  Last change:  16 September 2011
-#  Dutch language file by Rob Buitenhuis (rob _AT_ buitenhs.demon.nl)
-#  last input from him inserted: 27 December 2009
+#  Last change:  31 October 2011
+#  Dutch language file by Rob Buitenhuis (geo_AT_btnhs.nl)
+#  last input from him inserted: 10 October 2011
 #
 # 
 #  file langengl.tcl is consulted first; no need for duplicating entries here
@@ -312,7 +312,21 @@ array set MESS {
     badpluginparam "Foute plug-in parameters: lijst NAME EXPR, NAME begint met _"
     badpluginparamexec "Tijdens draaien plug-in %s, foutieve parameter: %s"
     pluginfailed "Plug-in %s faalde met boodschap: %s"
-    canwrtaux "Kan hulpbestand niet schrijven"
+    cantwrtdir "Kan niet in %s schrijven; wijzig aub de rechten"
+    cantcleandir "Kon directory %s niet leegmaken"
+    defTERMCMD "De optie voor het commando dat een terminal opent moet eerst worden gedefinieerd"
+    gpOutfile "Uitvoer is in bestand \"%s\" in je werk-directory."
+    gpQuitgnuplot "Druk op Enter in xterm window om gnuplot te verlaten."
+    gpModgnuplot "Wijzig het beeld in het Gnuplot-window\
+                  door de muis te slepen (linker en middelste knop).\n\
+                  Na sluiting van het gnuplot-window vind je\
+                  de uitvoer in bestand \"%s\" in je werk-directory."
+    htResult1 "Track=\"%s\""
+    htResult2 "Totale afstand=%s  Totale stijging=%s  Totale daling=%s"
+    htResult3 "Gebruikte totale tijd=%s  Tijd in rust=%s(%s)  Tijd in beweging=%s"
+    htResult4 "%s  Cap.vlak=%s  Cap.stijg=%s  Cap.afd=%s  Gesch. wandel tijd=%s"
+    srResult1 "Rust periodes (>5min) van track \"%s\""
+    badcumuls "Verschil in hoogte %s > totale stijging %s en/of daling %s; drempelwaarde hoogte %s %s optie moet worden aangepast"
 }
 
 set TXT(RTcompflds) "# WP {$DTUNIT} graad {$ALUNIT} et. beschr."
@@ -1326,6 +1340,61 @@ array set TXT {
     plugin  "Plug-in"
     unavailif  "Niet beschikbaar als"
     tclcode  "Tcl code"
+    PRJSphMerc "Sferisch Mercator"
+    PRJEPSG:3857 "EPSG:3857"
+    PRJEqCyl "Equidistant cilindrisch"
+    PRJEPSG:32663 "EPSG:32663"
+    gpTRtoGnuplot2d "Zij-aanzicht (Gnuplot)"
+    gpTRtoGnuplot2d_nb "Stuur track-gegevens naar extern programma  GNUPLOT en toon hoogte-schets"
+    gpTRtoGnuplot3d "Perspectief (Gnuplot)"
+    gpTRtoGnuplot3d_nb "Stuur track-gegevens naar extern programma GNUPLOT en toon 3D-schets"
+    gpParam2d "Parameters voor Gnuplot 2D-schets"
+    gpParam3d "Parameters voor Gnuplot 3D-schets"
+    gpFilename "Bestandsnaam"
+    gpCanwidth   "Breedte beeld"
+    gpCanheight  "Hoogte beeld"
+    gpSTotals  "Toon totalen"
+    gpLeft  "Linkerkant"
+    gpRight "Rechterkant"
+    gpNone  "Niets"
+    gpSRests "Toon rusten"
+    gpRest  "Rust"
+    gpSymText "Simbool+Tekst"
+    gpSymTime "Simbool+Tijd"
+    gpText  "Tekst"
+    gpSHours "Toon uren"
+    gpTimetop "Tijd boven"
+    gpTimebot "Tijd onder"
+    gpSSpeed "Toon snelheid"
+    gpHike  "Wandelen"
+    gpBike  "Fiets"
+    gpDrive "Auto"
+    gpGlide "Zweven"
+    gpLimitDist "Max. afstand WP tot Track (km)"
+    gpLimitStat "Min. afstand op Track voor zelfde WP (km)"
+    gpDirection "Richting"
+    gpForward "Vooruit"
+    gpBackward "Achteruit"
+    gp2D_hlp "Als er een groepsnaam gelijk aan de track-naam is,\n\
+              dan worden de waypoints van deze groep getoond\n\
+              met inachtneming van de gegeven afstanden.\n\
+              Als er geen passende groepsnaam bestaat,\
+              kun je kiezen uit een lijst of afbreken."
+    gpGenerated "Gemaakt met gnuplot door GPSMan"
+    gpModify "Wijzig aanzicht met de muis. Stop om plaatje te saven."
+    htCalcHikeTime "Bereken wandeltijd"
+    htCalcHikeTime_nb "Bereken wandeltijd met formule van DAV"
+    htHeader "Geschatte wandeltijd (zonder rusten) voor tracks\
+               gebruikmakend van de formule van de \"Deutscher Alpenverein\" met verschillende parameters"
+    htFooter1 "Capaciteit verwijst naar een uur."
+    htFooter2 "Aanbevolen rust-tijd is 20 min na twee uur (15%)."
+    srShowRest_nb "Toon rustperiodes > 5 min."
+    srTRTime   "Track-tijd"
+    srTotals   "Totalen"
+    optALTHRESHOLD "Drempelwaarde hoogte"
+    optDISPLAYCMD "Commando om kaartbeeld te tonen"
+    optTERMCMD "Commando om terminal-window te openen"
+    optMANHTTPADDR "HTTP-adres van het gebruikershandboek"
 }
 
     # the following definitions must be coherent with $TXT
