@@ -3,7 +3,7 @@
 #
 #  gpsman --- GPS Manager: a manager for GPS receiver data
 #
-# Copyright (c) 1998-2011 Miguel Filgueiras migf@portugalmail.pt
+# Copyright (c) 1998-2012 Miguel Filgueiras migf@portugalmail.pt
 #
 #    This program is free software; you can redistribute it and/or modify
 #      it under the terms of the GNU General Public License as published by
@@ -19,16 +19,16 @@
 #      along with this program.
 #
 #  File: main.tcl
-#  Last change:  21 September 2011
+#  Last change:  29 April 2012
 #
 
 # code here or called from here is not affected by patch files
 
-set VERSIONDATE(day) 21
-set VERSIONDATE(month) 9
-set VERSIONDATE(year) 2011
+set VERSIONDATE(day) 29
+set VERSIONDATE(month) 4
+set VERSIONDATE(year) 2012
 
-set VERSION 6.4.2
+set VERSION 6.4.3
 
       # these tests here prevent errors in the lang*.tcl files
 if { [lsearch -exact {KM NAUTMILE STATMILE} $DISTUNIT] == -1 } {
@@ -162,14 +162,14 @@ proc AboutInfo {w} {
     bind $frc.txt <Any-Key> break
     scrollbar $frc.tscrl -command "$frc.txt yview"
     $frc.txt insert 1.0 "Copyright (c) $VERSIONDATE(year) \
-Miguel Filgueiras / DCC-FC & LIACC / Universidade do Porto\n\
+Miguel Filgueiras\n\
 *   $TXT(errorsto) migf_AT_portugalmail.pt\n\
 $TXT(contrib):\n\
 *   Brian Baulch (baulchb_AT_onthenet.com.au)\n\
 *   Andreas Lange (Andreas.C.Lange_AT_GMX.de)\n\
 *   Alessandro Palmas (alpalmas_AT_tin.it)\n\
 *   Valere Robin (valere.robin_AT_wanadoo.fr)\n\
-*   Rob Buitenhuis (rob_AT_buitenhs.demon.nl)\n\
+*   Rob Buitenhuis (geo_AT_btnhs.nl)\n\
 *   Tri Agus Prayitno (acuss_AT_bk.or.id)\n\
 *   Matt Martin (matt.martin_AT_ieee.org)\n\
 *   Stefan Heine (stefan.heinen_AT_djh-freeweb.de)\n\
